#!/bin/sh
# the next line restarts using wish\
exec wish "$0" "$@" 

if {![info exists vTcl(sourcing)]} {

    # Provoke name search
    catch {package require bogus-package-name}
    set packageNames [package names]

    package require BWidget
    switch $tcl_platform(platform) {
	windows {
	}
	default {
	    option add *ScrolledWindow.size 14
	}
    }
    
    package require Tk
    switch $tcl_platform(platform) {
	windows {
            option add *Button.padY 0
	}
	default {
            option add *Scrollbar.width 10
            option add *Scrollbar.highlightThickness 0
            option add *Scrollbar.elementBorderWidth 2
            option add *Scrollbar.borderWidth 2
	}
    }
    
}

#############################################################################
# Visual Tcl v1.60 Project
#


#############################################################################
# vTcl Code to Load Stock Fonts


if {![info exist vTcl(sourcing)]} {
set vTcl(fonts,counter) 0
#############################################################################
## Procedure:  vTcl:font:add_font

proc ::vTcl:font:add_font {font_descr font_type {newkey {}}} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[info exists ::vTcl(fonts,$font_descr,object)]} {
        ## cool, it already exists
        return $::vTcl(fonts,$font_descr,object)
    }

     incr ::vTcl(fonts,counter)
     set newfont [eval font create $font_descr]
     lappend ::vTcl(fonts,objects) $newfont

     ## each font has its unique key so that when a project is
     ## reloaded, the key is used to find the font description
     if {$newkey == ""} {
          set newkey vTcl:font$::vTcl(fonts,counter)

          ## let's find an unused font key
          while {[vTcl:font:get_font $newkey] != ""} {
             incr ::vTcl(fonts,counter)
             set newkey vTcl:font$::vTcl(fonts,counter)
          }
     }

     set ::vTcl(fonts,$newfont,type)       $font_type
     set ::vTcl(fonts,$newfont,key)        $newkey
     set ::vTcl(fonts,$newfont,font_descr) $font_descr
     set ::vTcl(fonts,$font_descr,object)  $newfont
     set ::vTcl(fonts,$newkey,object)      $newfont

     lappend ::vTcl(fonts,$font_type) $newfont

     ## in case caller needs it
     return $newfont
}

#############################################################################
## Procedure:  vTcl:font:getFontFromDescr

proc ::vTcl:font:getFontFromDescr {font_descr} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[info exists ::vTcl(fonts,$font_descr,object)]} {
        return $::vTcl(fonts,$font_descr,object)
    } else {
        return ""
    }
}

vTcl:font:add_font \
    "-family helvetica -size 12" \
    stock \
    vTcl:font1
}
#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
#############################################################################
## Library Procedure:  Window

proc ::Window {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global vTcl
    foreach {cmd name newname} [lrange $args 0 2] {}
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[winfo exists $newname] && [wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}
#############################################################################
## Library Procedure:  vTcl:DefineAlias

proc ::vTcl:DefineAlias {target alias widgetProc top_or_alias cmdalias} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global widget
    set widget($alias) $target
    set widget(rev,$target) $alias
    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }
    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target
        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:DoCmdOption

proc ::vTcl:DoCmdOption {target cmd} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}
#############################################################################
## Library Procedure:  vTcl:FireEvent

proc ::vTcl:FireEvent {target event {params {}}} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## The window may have disappeared
    if {![winfo exists $target]} return
    ## Process each binding tag, looking for the event
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                foreach rep "\{%W $target\} $params" {
                    regsub -all [lindex $rep 0] $bind_code [lindex $rep 1] bind_code
                }
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    ## break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}
#############################################################################
## Library Procedure:  vTcl:Toplevel:WidgetProc

proc ::vTcl:Toplevel:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }
    set command [lindex $args 0]
    set args [lrange $args 1 end]
    switch -- [string tolower $command] {
        "setvar" {
            foreach {varname value} $args {}
            if {$value == ""} {
                return [set ::${w}::${varname}]
            } else {
                return [set ::${w}::${varname} $value]
            }
        }
        "hide" - "show" {
            Window [string tolower $command] $w
        }
        "showmodal" {
            ## modal dialog ends when window is destroyed
            Window show $w; raise $w
            grab $w; tkwait window $w; grab release $w
        }
        "startmodal" {
            ## ends when endmodal called
            Window show $w; raise $w
            set ::${w}::_modal 1
            grab $w; tkwait variable ::${w}::_modal; grab release $w
        }
        "endmodal" {
            ## ends modal dialog started with startmodal, argument is var name
            set ::${w}::_modal 0
            Window hide $w
        }
        default {
            uplevel $w $command $args
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:WidgetProc

proc ::vTcl:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }

    set command [lindex $args 0]
    set args [lrange $args 1 end]
    uplevel $w $command $args
}
#############################################################################
## Library Procedure:  vTcl:toplevel

proc ::vTcl:toplevel {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {set _modal 0}
}
}


if {[info exists vTcl(sourcing)]} {

proc vTcl:project:info {} {
    set base .top62
    namespace eval ::widgets::$base {
        set set,origin 0
        set set,size 1
        set runvisible 1
    }
    namespace eval ::widgets::$base.not63 {
        array set save {-activebackground 1 -background 1 -foreground 1 -height 1 -width 1}
        namespace eval subOptions {
            array set save {-activebackground 1 -activeforeground 1 -background 1 -foreground 1 -text 1}
        }
    }
    set site_4_0 [$base.not63 getframe page7]
    namespace eval ::widgets::$site_4_0 {
        array set save {-background 1 -borderwidth 1 -highlightcolor 1}
    }
    set site_4_0 $site_4_0
    namespace eval ::widgets::$site_4_0.cpd62 {
        array set save {-background 1 -font 1 -foreground 1 -insertbackground 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::$site_4_0.cpd63 {
        array set save {-command 1}
    }
    namespace eval ::widgets::$site_4_0.cpd64 {
        array set save {-activebackground 1 -background 1 -foreground 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.but67 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -foreground 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.cpd65 {
        array set save {-command 1 -cursor 1 -text 1}
    }
    set site_4_1 [$base.not63 getframe page1]
    namespace eval ::widgets::$site_4_1 {
        array set save {-background 1 -borderwidth 1 -highlightcolor 1}
    }
    set site_4_0 $site_4_1
    namespace eval ::widgets::$site_4_0.che70 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -foreground 1 -text 1 -variable 1}
    }
    namespace eval ::widgets::$site_4_0.but63 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.but66 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.cpd72 {
        array set save {-command 1 -cursor 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.cpd62 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.not62 {
        array set save {-background 1 -height 1 -width 1}
        namespace eval subOptions {
            array set save {-activebackground 1 -activeforeground 1 -background 1 -foreground 1 -text 1}
        }
    }
    set site_6_0 [$site_4_0.not62 getframe page1]
    namespace eval ::widgets::$site_6_0 {
        array set save {-borderwidth 1 -highlightcolor 1}
    }
    set site_6_0 $site_6_0
    namespace eval ::widgets::$site_6_0.cpd64 {
        array set save {-command 1}
    }
    namespace eval ::widgets::$site_6_0.cpd65 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_6_0.cpd66 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_6_0.cpd67 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_6_0.cpd63 {
        array set save {-background 1 -foreground 1 -listvariable 1 -selectmode 1 -yscrollcommand 1}
    }
    set site_6_1 [$site_4_0.not62 getframe page2]
    namespace eval ::widgets::$site_6_1 {
        array set save {-borderwidth 1 -highlightcolor 1}
    }
    set site_6_0 $site_6_1
    namespace eval ::widgets::$site_6_0.cpd68 {
        array set save {-background 1 -foreground 1 -listvariable 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::$site_6_0.cpd69 {
        array set save {-command 1}
    }
    namespace eval ::widgets::$site_6_0.cpd70 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_6_0.cpd71 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_6_0.cpd72 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.lab63 {
        array set save {-activebackground 1 -background 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.tex70 {
        array set save {-background 1 -insertbackground 1}
    }
    namespace eval ::widgets::$site_4_0.cpd71 {
        array set save {-command 1 -text 1}
    }
    set site_4_2 [$base.not63 getframe page2]
    namespace eval ::widgets::$site_4_2 {
        array set save {-background 1 -borderwidth 1 -highlightcolor 1}
    }
    set site_4_0 $site_4_2
    namespace eval ::widgets::$site_4_0.cpd71 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.cpd76 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.ent77 {
        array set save {-background 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_4_0.lab78 {
        array set save {-background 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.cpd63 {
        array set save {-command 1 -cursor 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.cpd70 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.cpd67 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.not62 {
        array set save {-height 1 -width 1}
        namespace eval subOptions {
            array set save {-activebackground 1 -activeforeground 1 -background 1 -foreground 1 -text 1}
        }
    }
    set site_6_0 [$site_4_0.not62 getframe page1]
    namespace eval ::widgets::$site_6_0 {
        array set save {-borderwidth 1 -highlightcolor 1}
    }
    set site_6_0 $site_6_0
    namespace eval ::widgets::$site_6_0.lis63 {
        array set save {-background 1 -foreground 1 -listvariable 1 -selectmode 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::$site_6_0.scr66 {
        array set save {-command 1}
    }
    namespace eval ::widgets::$site_6_0.but68 {
        array set save {-command 1 -text 1}
    }
    set site_6_1 [$site_4_0.not62 getframe page2]
    namespace eval ::widgets::$site_6_1 {
        array set save {-borderwidth 1 -highlightcolor 1}
    }
    set site_6_0 $site_6_1
    namespace eval ::widgets::$site_6_0.lis65 {
        array set save {-background 1 -foreground 1 -listvariable 1 -selectmode 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::$site_6_0.scr67 {
        array set save {-command 1}
    }
    namespace eval ::widgets::$site_6_0.but69 {
        array set save {-command 1 -text 1}
    }
    set site_4_3 [$base.not63 getframe page4]
    namespace eval ::widgets::$site_4_3 {
        array set save {-borderwidth 1 -highlightcolor 1}
    }
    set site_4_0 $site_4_3
    namespace eval ::widgets::$site_4_0.ent69 {
        array set save {-background 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_4_0.lab71 {
        array set save {-background 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.lab77 {
        array set save {-background 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.ent78 {
        array set save {-background 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_4_0.ent80 {
        array set save {-background 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_4_0.ent82 {
        array set save {-background 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_4_0.but62 {
        array set save {-command 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.cpd62 {
        array set save {-background 1 -highlightbackground 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.cpd63 {
        array set save {-background 1 -highlightbackground 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.cpd64 {
        array set save {-background 1 -insertbackground 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_4_0.cpd65 {
        array set save {-background 1 -text 1}
    }
    namespace eval ::widgets::$base.m64 {
        array set save {-tearoff 1}
    }
    namespace eval ::widgets::$base.cpd66 {
        array set save {-listvariable 1 -yscrollcommand 1}
    }
    namespace eval ::widgets_bindings {
        set tagslist _TopLevel
    }
    namespace eval ::vTcl::modules::main {
        set procs {
            init
            main
        }
        set compounds {
        }
        set projectType single
    }
}
}

#################################
# USER DEFINED PROCEDURES
#
#############################################################################
## Procedure:  main

proc ::main {argc argv} {
# Set cdtar location
global cdtarlocation
set cdtarlocation [file dirname [info script]]


if {![file exist ~/.cdtar/config.rc]} then { 
    if {![file exist ~/.cdtar]} then { file mkdir ~/.cdtar }
    file copy $cdtarlocation/config.rc ~/.cdtar/config.rc 
    }

set filename ~/.cdtar/config.rc
set fileid [open $filename r]
set data [read $fileid]
close $fileid
eval $data

global varDevid varDevname varSpeed varTemp varSize varOutput varPath varIncr
set varDevid $devid 
set varDevname $devmnt
set varSpeed $speed
set varTemp $tarfile 
set varSize $size
set varOutput $output
set varPath /tmp
set varIncr ~/.cdtar/cdtar-incremental.dif

#display cdtar-exclude.txt
if {![file exist ~/.cdtar/cdtar-exclude.txt]} then { 
    if {![file exist ~/.cdtar]} then { file mkdir ~/.cdtar }
    file copy $cdtarlocation/cdtar-exclude.txt ~/.cdtar/cdtar-exclude.txt
    }
set filename ~/.cdtar/cdtar-exclude.txt
set fileid [open $filename r]

while  {![eof $fileid]} {
gets $fileid varExclude
if {"$varExclude"!=""} then {
varExclude insert end $varExclude }
                        }
close $fileid


#display cdtar-include.txt
if {![file exist ~/.cdtar/cdtar-include.txt]} then { 
    if {![file exist ~/.cdtar]} then { file mkdir ~/.cdtar }
    file copy $cdtarlocation/cdtar-include.txt ~/.cdtar/cdtar-include.txt
    }
set filename ~/.cdtar/cdtar-include.txt
set fileid [open $filename r]

while  {![eof $fileid]} {
gets $fileid varInclude
if {"$varInclude"!=""} then {
.top62.not63.fpage1.not62.fpage1.cpd63 insert end $varInclude }
                        }
close $fileid


#erase output file
set filename "~/.cdtar/output.txt"
set fileid [open $filename w]
puts $fileid "Output window"
flush $fileid
close $fileid

#erase catalog file
set filename "~/.cdtar/catalog.txt"
set fileid [open $filename w]
puts $fileid "You need to retrieve the catalog first."
flush $fileid
close $fileid


# remove lock button file
if {[file exist ~/.cdtar/lckbtn]} then {
file delete ~/.cdtar/lckbtn } 

########################### Procedures below ##############################


proc lckbttn {} {
if {[file exist ~/.cdtar/lckbtn]} then {return "locked"}
}


global varToggleout
set varToggleout 0
after 3000 updateout
after 3000 incremental

proc updateout {} {
        global varToggleout
        if {$varToggleout==1} then {return}
        varCmdout delete 0.0 end
        set filename ~/.cdtar/output.txt
        set fileid [open $filename r]
        set data [read $fileid]
        close $fileid
        varCmdout insert end $data
        varCmdout see end
        after 500 updateout
}

proc incremental {} {
.top62.not63.fpage1.tex70 insert 1.0 "cdtar-incremental.dif"
}

proc comit_selections {} {
    # TAR Include
    set filename ~/.cdtar/cdtar-include.txt
    set fileid [open $filename w]
    set sizeSelect [.top62.not63.fpage1.not62.fpage1.cpd63 index end]
    set x 0
        while {$x < $sizeSelect}  {
        puts $fileid [.top62.not63.fpage1.not62.fpage1.cpd63 get $x]
        incr x 1
                                   }
    close $fileid

    # Tar Exclude
    set filename ~/.cdtar/cdtar-exclude.txt
    set fileid [open $filename w]
    set sizeExclude [varExclude index end]
    set x 0
        while {$x < $sizeExclude}  {
        puts $fileid [varExclude get $x]
        incr x 1
                                    }
    close $fileid

    # TAR Restore
    set filename ~/.cdtar/cdtar-restore.txt
    set fileid [open $filename w]
    set sizeSelect [varRestore index end]
    set x 0
        while {$x < $sizeSelect}  {
        puts $fileid [varRestore get $x]
        incr x 1
                                   }
    close $fileid

                                                }
}

#############################################################################
## Initialization Procedure:  init

proc ::init {argc argv} {

}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    wm focusmodel $top passive
    wm geometry $top 1x1+0+0; update
    wm maxsize $top 1009 738
    wm minsize $top 1 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm withdraw $top
    wm title $top "vtcl.tcl"
    bindtags $top "$top Vtcl.tcl all"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top62 {base} {
    if {$base == ""} {
        set base .top62
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    set top $base
    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $top -class Toplevel \
        -menu "$top.m64" -highlightcolor black 
    wm focusmodel $top passive
    wm geometry $top 594x384; update
    wm maxsize $top 1009 738
    wm minsize $top 1 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm deiconify $top
    wm title $top "CDTARchive"
    vTcl:DefineAlias "$top" "Toplevel1" vTcl:Toplevel:WidgetProc "" 1
    bindtags $top "$top Toplevel all _TopLevel"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    NoteBook $top.not63 \
        -activebackground #999999 -background #999999 -foreground #0000ff \
        -height 416 -width 599 
    vTcl:DefineAlias "$top.not63" "NoteBook1" vTcl:WidgetProc "Toplevel1" 1
    $top.not63 insert end page7 \
        -activebackground #f7fbf7 -activeforeground black -background #d9d9d9 \
        -foreground black -text Status 
    $top.not63 insert end page1 \
        -activebackground #f7fbf7 -activeforeground black -background #d9d9d9 \
        -foreground black -text Backup 
    $top.not63 insert end page2 \
        -activebackground #f7fbf7 -activeforeground black -background #d9d9d9 \
        -foreground black -text Restore 
    $top.not63 insert end page4 \
        -activebackground #f7fbf7 -activeforeground black -background #d9d9d9 \
        -foreground black -text Settings 
    set site_4_0 [$top.not63 getframe page7]
    text $site_4_0.cpd62 \
        -background #000000 \
        -font [vTcl:font:getFontFromDescr "-family helvetica -size 12"] \
        -foreground #00ff00 -insertbackground black \
        -yscrollcommand "$site_4_0.cpd63 set" 
    vTcl:DefineAlias "$site_4_0.cpd62" "varCmdout" vTcl:WidgetProc "Toplevel1" 1
    scrollbar $site_4_0.cpd63 \
        -command "$site_4_0.cpd62 yview" 
    vTcl:DefineAlias "$site_4_0.cpd63" "Scrollbar3" vTcl:WidgetProc "Toplevel1" 1
    label $site_4_0.cpd64 \
        -activebackground #999999 -background #000000 -foreground #00ff00 \
        -text {Command Output} 
    vTcl:DefineAlias "$site_4_0.cpd64" "Label11" vTcl:WidgetProc "Toplevel1" 1
    button $site_4_0.but67 \
        -activebackground #009900 -activeforeground #ffffff \
        -background #cccccc \
        -command {if {"$varToggleout"=="1"} then {
set varToggleout 0
} else {
set varToggleout 1
}

updateout} \
        -foreground #000000 -text {Auto scroll} 
    vTcl:DefineAlias "$site_4_0.but67" "Button3" vTcl:WidgetProc "Toplevel1" 1
    button $site_4_0.cpd65 \
        -command {exec $cdtarlocation/stop &} -cursor pirate -text Cancel 
    vTcl:DefineAlias "$site_4_0.cpd65" "Button7" vTcl:WidgetProc "Toplevel1" 1
    place $site_4_0.cpd62 \
        -in $site_4_0 -x 10 -y 40 -width 560 -height 316 -anchor nw \
        -bordermode ignore 
    place $site_4_0.cpd63 \
        -in $site_4_0 -x 569 -y 39 -width 16 -height 317 -anchor nw \
        -bordermode ignore 
    place $site_4_0.cpd64 \
        -in $site_4_0 -x 230 -y 20 -width 113 -height 22 -anchor nw \
        -bordermode ignore 
    place $site_4_0.but67 \
        -in $site_4_0 -x 10 -y 8 -width 74 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_4_0.cpd65 \
        -in $site_4_0 -x 513 -y 9 -width 65 -height 27 -anchor nw \
        -bordermode ignore 
    set site_4_1 [$top.not63 getframe page1]
    checkbutton $site_4_1.che70 \
        -activebackground #cccccc -activeforeground #000000 \
        -background #cccccc -foreground #000000 \
        -text {backup changed file(s)} -variable btnChanged 
    vTcl:DefineAlias "$site_4_1.che70" "btnChanged" vTcl:WidgetProc "Toplevel1" 1
    button $site_4_1.but63 \
        \
        -command [list vTcl:DoCmdOption $site_4_1.but63 {if {"[lckbttn]"=="locked"} then {} else {
#begin unlocked

if $btnChanged==1 then {

##Differential
tk_messageBox -message "Backup only Changed files since last backup!"
    if [ file exist ~/.cdtar/cdtar-incremental.dif ] then {
        #save previous incremntal file as a backup should someone want it still.
        set ftime [file mtime ~/.cdtar/cdtar-incremental.dif]
        set engtime [clock format $ftime -format %m-%d-%y-%H%M]
        file copy -force ~/.cdtar/cdtar-incremental.dif ~/.cdtar/cdtar-incremental-$engtime.dif
        if {"$varIncr"!="~/.cdtar/cdtar-incremental.dif"}  then {
            file copy -force $varIncr ~/.cdtar/cdtar-incremental.dif
                                                            }
                                                            }

} else {


#Full Backup
tk_messageBox -message "Perform a full backup of selected files!"
    if [ file exist ~/.cdtar/cdtar-incremental.dif ] then {
        #save previous incremntal file as a backup should someone want it still.

        set ftime [file mtime ~/.cdtar/cdtar-incremental.dif]
        set engtime [clock format $ftime -format %m-%d-%y-%H%M]
        file copy -force ~/.cdtar/cdtar-incremental.dif ~/.cdtar/cdtar-incremental-$engtime.dif
        file delete ~/.cdtar/cdtar-incremental.dif
                                                          }
        }


set varStart [tk_messageBox -icon question -message "Continue?" -title "CDTAR" -type yesno]
if {"$varStart"=="yes"} then {

# save selections from include and exclude
comit_selections
exec $cdtarlocation/backup $varDevid $varDevname $varSize $varSpeed $varTemp > ~/.cdtar/output.txt &
exec $cdtarlocation/lckbtn.sh

#Change to the Status tab
.top62.not63 raise page7
                            }
                            
                            
#end unlocked                          
					}}] \
        -text Backup 
    vTcl:DefineAlias "$site_4_1.but63" "btnBackup" vTcl:WidgetProc "Toplevel1" 1
    button $site_4_1.but66 \
        \
        -command {if {"[lckbttn]"=="locked"} then {} else {
#begin unlocked

tk_messageBox -message "Will eject when done!" -title "CDTAR"
exec cdrecord -v blank=fast -dev=$varDevid -eject > ~/.cdtar/output.txt &

#Change to the Status tab
.top62.not63 raise page7
#end unlocked                          
					}} \
        -text {Blank RW} 
    vTcl:DefineAlias "$site_4_1.but66" "Button2" vTcl:WidgetProc "Toplevel1" 1
    button $site_4_1.cpd72 \
        -command {exec $cdtarlocation/stop &} -cursor pirate -text Cancel 
    vTcl:DefineAlias "$site_4_1.cpd72" "Button1" vTcl:WidgetProc "Toplevel1" 1
    button $site_4_1.cpd62 \
        \
        -command {if {"[lckbttn]"=="locked"} then {} else {
#begin unlocked

set varStart [tk_messageBox -icon question -message "Compare Continue?" -title "CDTAR" -type yesno]
if {"$varStart"=="yes"} then {

# save selections from include and exclude
comit_selections
exec $cdtarlocation/compare $varDevid $varDevname $varSize $varSpeed $varTemp > ~/.cdtar/output.txt &
exec $cdtarlocation/lckbtn.sh

#Change to the Status tab
.top62.not63 raise page7

                             }
                            
                            
#end unlocked                          
					}} \
        -text Compare 
    vTcl:DefineAlias "$site_4_1.cpd62" "btnBackup3" vTcl:WidgetProc "Toplevel1" 1
    NoteBook $site_4_1.not62 \
        -background #cccccc -height 271 -width 559 
    vTcl:DefineAlias "$site_4_1.not62" "NoteBook2" vTcl:WidgetProc "Toplevel1" 1
    $site_4_1.not62 insert end page1 \
        -activebackground #f7fbf7 -activeforeground black -background #d9d9d9 \
        -foreground black -text Include 
    $site_4_1.not62 insert end page2 \
        -activebackground #f7fbf7 -activeforeground black -background #d9d9d9 \
        -foreground black -text Exclude 
    set site_6_0 [$site_4_1.not62 getframe page1]
    scrollbar $site_6_0.cpd64 \
        -command "$site_6_0.cpd63 yview" 
    vTcl:DefineAlias "$site_6_0.cpd64" "Scrollbar1" vTcl:WidgetProc "Toplevel1" 1
    button $site_6_0.cpd65 \
        \
        -command {set foldername [tk_chooseDirectory]

if {$foldername != ""} then {
.top62.not63.fpage1.not62.fpage1.cpd63 insert end $foldername
    }} \
        -text {Add Directory(s)} 
    vTcl:DefineAlias "$site_6_0.cpd65" "Add Directory1" vTcl:WidgetProc "Toplevel1" 1
    button $site_6_0.cpd66 \
        \
        -command {set filename [tk_getOpenFile]

if {$filename != ""} then {
.top62.not63.fpage1.not62.fpage1.cpd63 insert end $filename
    }} \
        -text {Add File(s)} 
    vTcl:DefineAlias "$site_6_0.cpd66" "Add Directory1" vTcl:WidgetProc "Toplevel1" 1
    button $site_6_0.cpd67 \
        \
        -command {#get selection
set numselect [.top62.not63.fpage1.not62.fpage1.cpd63 curselection]

#remove from the list
set varnumbersUnsort [.top62.not63.fpage1.not62.fpage1.cpd63 curselection]

#sort selection
set varnumbersSort [lsort -decreasing -integer $varnumbersUnsort]
#tk_messageBox -message $varnumbersSort

#delete selection
foreach varselected $varnumbersSort {
.top62.not63.fpage1.not62.fpage1.cpd63 delete $varselected
}} \
        -text Remove 
    vTcl:DefineAlias "$site_6_0.cpd67" "brnRemove1" vTcl:WidgetProc "Toplevel1" 1
    listbox $site_6_0.cpd63 \
        -background #000099 -foreground #ffffff -selectmode extended \
        -yscrollcommand "$site_6_0.cpd64 set" -listvariable "$top\::lis66" 
    bind $site_6_0.cpd63 <FocusIn> {
        # TODO: your event handler here
    }
    place $site_6_0.cpd64 \
        -in $site_6_0 -x 530 -y 6 -width 21 -height 235 -anchor nw \
        -bordermode ignore 
    place $site_6_0.cpd65 \
        -in $site_6_0 -x 14 -y 10 -width 122 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_6_0.cpd66 \
        -in $site_6_0 -x 149 -y 10 -width 88 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_6_0.cpd67 \
        -in $site_6_0 -x 252 -y 10 -width 73 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_6_0.cpd63 \
        -in $site_6_0 -x 15 -y 39 -width 528 -height 202 -anchor nw \
        -bordermode ignore 
    set site_6_1 [$site_4_1.not62 getframe page2]
    listbox $site_6_1.cpd68 \
        -background #990000 -foreground #ffffff \
        -yscrollcommand "$site_6_1.cpd69 set" -listvariable "$top\::lis67" 
    vTcl:DefineAlias "$site_6_1.cpd68" "varExclude" vTcl:WidgetProc "Toplevel1" 1
    scrollbar $site_6_1.cpd69 \
        -command "$site_6_1.cpd68 yview" 
    vTcl:DefineAlias "$site_6_1.cpd69" "Scrollbar2" vTcl:WidgetProc "Toplevel1" 1
    button $site_6_1.cpd70 \
        \
        -command {set foldername [tk_chooseDirectory]

if {$foldername != ""} then {
varExclude insert end $foldername
    }} \
        -text {Add Directory(s)} 
    vTcl:DefineAlias "$site_6_1.cpd70" "Add Directory1" vTcl:WidgetProc "Toplevel1" 1
    button $site_6_1.cpd71 \
        \
        -command {set filename [tk_getOpenFile]

if {$filename != ""} then {
varExclude insert end $filename
    }} \
        -text {Add File(s)} 
    vTcl:DefineAlias "$site_6_1.cpd71" "Add Directory1" vTcl:WidgetProc "Toplevel1" 1
    button $site_6_1.cpd72 \
        \
        -command {set numSelect [varExclude curselection]
if {$numSelect != ""} then {
varExclude delete $numSelect
}} \
        -text Remove 
    vTcl:DefineAlias "$site_6_1.cpd72" "remove2" vTcl:WidgetProc "Toplevel1" 1
    place $site_6_1.cpd68 \
        -in $site_6_1 -x 15 -y 39 -width 518 -height 202 -anchor nw \
        -bordermode ignore 
    place $site_6_1.cpd69 \
        -in $site_6_1 -x 530 -y 6 -width 21 -height 235 -anchor nw \
        -bordermode ignore 
    place $site_6_1.cpd70 \
        -in $site_6_1 -x 14 -y 10 -width 122 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_6_1.cpd71 \
        -in $site_6_1 -x 149 -y 10 -width 88 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_6_1.cpd72 \
        -in $site_6_1 -x 252 -y 10 -width 73 -height 28 -anchor nw \
        -bordermode ignore 
    $site_4_1.not62 raise page1
    label $site_4_1.lab63 \
        -activebackground #cccccc -background #999999 \
        -text {incremental backup file to use} 
    vTcl:DefineAlias "$site_4_1.lab63" "Label4" vTcl:WidgetProc "Toplevel1" 1
    text $site_4_1.tex70 \
        -background white -insertbackground black 
    vTcl:DefineAlias "$site_4_1.tex70" "varIncr" vTcl:WidgetProc "Toplevel1" 1
    button $site_4_1.cpd71 \
        \
        -command {set ftype { { "incremental files" .dif } { "All Files" * }}
set filename [tk_getOpenFile -filetypes $ftype -initialdir "~/.cdtar"]

if {$filename != ""} then {
.top62.not63.fpage1.tex70 delete 1.0 end
.top62.not63.fpage1.tex70 insert end [file tail $filename]
set varIncr $filename
    }} \
        -text Choose 
    vTcl:DefineAlias "$site_4_1.cpd71" "Add Directory1" vTcl:WidgetProc "Toplevel1" 1
    place $site_4_1.che70 \
        -in $site_4_1 -x 88 -y 10 -width 167 -height 24 -anchor nw \
        -bordermode ignore 
    place $site_4_1.but63 \
        -in $site_4_1 -x 14 -y 10 -width 64 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_4_1.but66 \
        -in $site_4_1 -x 95 -y 46 -width 63 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_4_1.cpd72 \
        -in $site_4_1 -x 177 -y 45 -width 52 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_4_1.cpd62 \
        -in $site_4_1 -x 14 -y 46 -width 64 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_4_1.not62 \
        -in $site_4_1 -x 15 -y 85 -width 559 -height 271 -anchor nw \
        -bordermode ignore 
    place $site_4_1.lab63 \
        -in $site_4_1 -x 325 -y 11 -width 190 -height 22 -anchor nw \
        -bordermode ignore 
    place $site_4_1.tex70 \
        -in $site_4_1 -x 265 -y 38 -width 309 -height 20 -anchor nw \
        -bordermode ignore 
    place $site_4_1.cpd71 \
        -in $site_4_1 -x 265 -y 10 -width 58 -height 23 -anchor nw \
        -bordermode ignore 
    set site_4_2 [$top.not63 getframe page2]
    button $site_4_2.cpd71 \
        \
        -command {if {"[lckbttn]"=="locked"} then {} else {
#begin unlocked

set varStart [tk_messageBox -icon question -message "Continue?" -title "CDTAR" -type yesno]
if {"$varStart"=="yes"} then {
exec $cdtarlocation/listfiles $varDevid $varDevname $varSize $varSpeed $varTemp > ~/.cdtar/output.txt &
exec $cdtarlocation/lckbtn.sh

#Change to the Status tab
.top62.not63 raise page7

                            }

#end unlocked                          }} \
        -text {Retrieve Catalog} 
    vTcl:DefineAlias "$site_4_2.cpd71" "btnBackup1" vTcl:WidgetProc "Toplevel1" 1
    button $site_4_2.cpd76 \
        \
        -command {if {"[lckbttn]"=="locked"} then {} else {
#begin unlocked

set varStart [tk_messageBox -icon question -message "Continue with restore?" -title "CDTAR" -type yesno]
if {"$varStart"=="yes"} then {


if ![file exists $varPath] then {
file mkdir $varPath
}

# save selections from include and exclude
comit_selections
exec $cdtarlocation/restore $varDevid $varDevname $varSize $varSpeed $varTemp $varPath > ~/.cdtar/output.txt &
exec $cdtarlocation/lckbtn.sh 

#Change to the Status tab
.top62.not63 raise page7

                            }
                           
#end unlocked
                                 }} \
        -text Restore 
    vTcl:DefineAlias "$site_4_2.cpd76" "btnBackup2" vTcl:WidgetProc "Toplevel1" 1
    entry $site_4_2.ent77 \
        -background white -insertbackground black -textvariable varPath 
    vTcl:DefineAlias "$site_4_2.ent77" "Entry1" vTcl:WidgetProc "Toplevel1" 1
    label $site_4_2.lab78 \
        -background #999999 -text {Restore to path } 
    vTcl:DefineAlias "$site_4_2.lab78" "Label3" vTcl:WidgetProc "Toplevel1" 1
    button $site_4_2.cpd63 \
        -command {exec $cdtarlocation/stop &} -cursor pirate -text Cancel 
    vTcl:DefineAlias "$site_4_2.cpd63" "Button5" vTcl:WidgetProc "Toplevel1" 1
    button $site_4_2.cpd70 \
        \
        -command {if {"[lckbttn]"=="locked"} then {} else {
#begin unlocked

#tk_messageBox -message "Updates the list below!" -title "CDTAR"

##display cdtar-include.txt
varList delete 0 end
set filename ~/.cdtar/catalog.txt
set fileid [open $filename r]

while  {![eof $fileid]} {
gets $fileid varInclude
if {"$varInclude"!=""} then {
varList insert end $varInclude }
                        }
close $fileid

#end unlocked 
                         }} \
        -text {Import Catalog} 
    vTcl:DefineAlias "$site_4_2.cpd70" "btnBackup4" vTcl:WidgetProc "Toplevel1" 1
    button $site_4_2.cpd67 \
        \
        -command {if {"[lckbttn]"=="locked"} then {} else {
#begin unlocked

#tk_messageBox -message "Adds *.* to Restore!" -title "CDTAR"

##display cdtar-include.txt
varList delete 0 end
varList insert end "*.*"

varRestore delete 0 end
varRestore insert end "*.*"

#end unlocked 
                         }} \
        -text {Add *.*} 
    vTcl:DefineAlias "$site_4_2.cpd67" "Add Directory1" vTcl:WidgetProc "Toplevel1" 1
    NoteBook $site_4_2.not62 \
        -height 231 -width 564 
    $site_4_2.not62 insert end page1 \
        -activebackground #f7fbf7 -activeforeground black -background #d9d9d9 \
        -foreground black -text Catalog 
    $site_4_2.not62 insert end page2 \
        -activebackground #f7fbf7 -activeforeground black -background #d9d9d9 \
        -foreground black -text Selected 
    set site_6_0 [$site_4_2.not62 getframe page1]
    listbox $site_6_0.lis63 \
        -background #999900 -foreground #ffffff -selectmode extended \
        -yscrollcommand "$site_6_0.scr66 set" -listvariable "$top\::lis63" 
    vTcl:DefineAlias "$site_6_0.lis63" "varList" vTcl:WidgetProc "Toplevel1" 1
    scrollbar $site_6_0.scr66 \
        -command "$site_6_0.lis63 yview" 
    vTcl:DefineAlias "$site_6_0.scr66" "Scrollbar4" vTcl:WidgetProc "Toplevel1" 1
    button $site_6_0.but68 \
        \
        -command {#get selection
set numselect [varList curselection]

#selection list
set varnumbersUnsort [varList curselection]

#sort selection
set varnumbersSort [lsort -decreasing -integer $varnumbersUnsort]

#Add selection to restore
foreach varselected $varnumbersSort {
varRestore insert end [varList get $varselected]
                                    }} \
        -text Add 
    vTcl:DefineAlias "$site_6_0.but68" "Button4" vTcl:WidgetProc "Toplevel1" 1
    place $site_6_0.lis63 \
        -in $site_6_0 -x 15 -y 39 -width 516 -height 202 -anchor nw \
        -bordermode ignore 
    place $site_6_0.scr66 \
        -in $site_6_0 -x 530 -y 7 -width 21 -height 233 -anchor nw \
        -bordermode ignore 
    place $site_6_0.but68 \
        -in $site_6_0 -x 15 -y 11 -width 49 -height 27 -anchor nw \
        -bordermode ignore 
    set site_6_1 [$site_4_2.not62 getframe page2]
    listbox $site_6_1.lis65 \
        -background #009900 -foreground #ffffff -selectmode extended \
        -yscrollcommand "$site_6_1.scr67 set" -listvariable "$top\::lis65" 
    vTcl:DefineAlias "$site_6_1.lis65" "varRestore" vTcl:WidgetProc "Toplevel1" 1
    scrollbar $site_6_1.scr67 \
        -command "$site_6_1.lis65 yview" 
    vTcl:DefineAlias "$site_6_1.scr67" "Scrollbar5" vTcl:WidgetProc "Toplevel1" 1
    button $site_6_1.but69 \
        \
        -command {#get selection
set numselect [varRestore curselection]

#remove from the list
set varnumbersUnsort [varRestore curselection]

#sort selection
set varnumbersSort [lsort -decreasing -integer $varnumbersUnsort]
#tk_messageBox -message $varnumbersSort

#delete selection
foreach varselected $varnumbersSort {
varRestore delete $varselected
}} \
        -text Remove 
    vTcl:DefineAlias "$site_6_1.but69" "Button6" vTcl:WidgetProc "Toplevel1" 1
    place $site_6_1.lis65 \
        -in $site_6_1 -x 15 -y 39 -width 516 -height 202 -anchor nw \
        -bordermode ignore 
    place $site_6_1.scr67 \
        -in $site_6_1 -x 530 -y 7 -width 21 -height 233 -anchor nw \
        -bordermode ignore 
    place $site_6_1.but69 \
        -in $site_6_1 -x 15 -y 11 -width 73 -height 27 -anchor nw \
        -bordermode ignore 
    $site_4_2.not62 raise page1
    place $site_4_2.cpd71 \
        -in $site_4_2 -x 14 -y 10 -width 124 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_4_2.cpd76 \
        -in $site_4_2 -x 153 -y 47 -width 63 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_4_2.ent77 \
        -in $site_4_2 -x 340 -y 5 -width 243 -height 24 -anchor nw \
        -bordermode ignore 
    place $site_4_2.lab78 \
        -in $site_4_2 -x 235 -y 7 -width 108 -height 22 -anchor nw \
        -bordermode ignore 
    place $site_4_2.cpd63 \
        -in $site_4_2 -x 230 -y 46 -width 62 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_4_2.cpd70 \
        -in $site_4_2 -x 14 -y 47 -width 124 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_4_2.cpd67 \
        -in $site_4_2 -x 153 -y 8 -width 63 -height 28 -anchor nw \
        -bordermode ignore 
    place $site_4_2.not62 \
        -in $site_4_2 -x 15 -y 85 -width 559 -height 271 -anchor nw \
        -bordermode ignore 
    set site_4_3 [$top.not63 getframe page4]
    entry $site_4_3.ent69 \
        -background white -insertbackground black -textvariable varDevid 
    vTcl:DefineAlias "$site_4_3.ent69" "varDevid" vTcl:WidgetProc "Toplevel1" 1
    label $site_4_3.lab71 \
        -background #999999 -text {Device ID example: 0,0,0} 
    vTcl:DefineAlias "$site_4_3.lab71" "Label1" vTcl:WidgetProc "Toplevel1" 1
    label $site_4_3.lab77 \
        -background #999999 -text {Speed example: 16} 
    vTcl:DefineAlias "$site_4_3.lab77" "Label8" vTcl:WidgetProc "Toplevel1" 1
    entry $site_4_3.ent78 \
        -background white -insertbackground black -textvariable varSpeed 
    vTcl:DefineAlias "$site_4_3.ent78" "varSpeed" vTcl:WidgetProc "Toplevel1" 1
    entry $site_4_3.ent80 \
        -background white -insertbackground black -textvariable varSize 
    vTcl:DefineAlias "$site_4_3.ent80" "varSize" vTcl:WidgetProc "Toplevel1" 1
    entry $site_4_3.ent82 \
        -background white -insertbackground black -textvariable varTemp 
    vTcl:DefineAlias "$site_4_3.ent82" "varTmpfile" vTcl:WidgetProc "Toplevel1" 1
    button $site_4_3.but62 \
        \
        -command {set filename ~/.cdtar/config.rc
set fileid [open $filename w]

puts $fileid "set devid $varDevid"
puts $fileid "set devmnt $varDevname"
puts $fileid "set speed $varSpeed"
puts $fileid "set tarfile $varTemp"
puts $fileid "set size $varSize"
puts $fileid "set output $varOutput"

flush $fileid
close $fileid
tk_messageBox -message "Configuration saved!"} \
        -text Apply 
    vTcl:DefineAlias "$site_4_3.but62" "btnApply" vTcl:WidgetProc "Toplevel1" 1
    label $site_4_3.cpd62 \
        -background #999999 -highlightbackground #999999 \
        -text {Size in Kbytes of CDR
Example 700MB = 716100} 
    vTcl:DefineAlias "$site_4_3.cpd62" "Label12" vTcl:WidgetProc "Toplevel1" 1
    label $site_4_3.cpd63 \
        -background #999999 -highlightbackground #999999 \
        -text {Device name 
example: /mnt/cdrom} 
    vTcl:DefineAlias "$site_4_3.cpd63" "Label13" vTcl:WidgetProc "Toplevel1" 1
    entry $site_4_3.cpd64 \
        -background white -insertbackground black -textvariable varDevname 
    vTcl:DefineAlias "$site_4_3.cpd64" "varSize1" vTcl:WidgetProc "Toplevel1" 1
    label $site_4_3.cpd65 \
        -background #999999 -text {Temp Folder} 
    vTcl:DefineAlias "$site_4_3.cpd65" "Label2" vTcl:WidgetProc "Toplevel1" 1
    place $site_4_3.ent69 \
        -in $site_4_3 -x 185 -y 25 -width 63 -height 24 -anchor nw \
        -bordermode ignore 
    place $site_4_3.lab71 \
        -in $site_4_3 -x 25 -y 25 -width 154 -height 22 -anchor nw \
        -bordermode ignore 
    place $site_4_3.lab77 \
        -in $site_4_3 -x 55 -y 60 -width 124 -height 22 -anchor nw \
        -bordermode ignore 
    place $site_4_3.ent78 \
        -in $site_4_3 -x 185 -y 60 -width 63 -height 24 -anchor nw \
        -bordermode ignore 
    place $site_4_3.ent80 \
        -in $site_4_3 -x 185 -y 99 -width 63 -height 24 -anchor nw \
        -bordermode ignore 
    place $site_4_3.ent82 \
        -in $site_4_3 -x 339 -y 25 -width 243 -height 24 -anchor nw \
        -bordermode ignore 
    place $site_4_3.but62 \
        -in $site_4_3 -x 525 -y 100 -anchor nw -bordermode ignore 
    place $site_4_3.cpd62 \
        -in $site_4_3 -x 25 -y 92 -width 155 -height 38 -anchor nw \
        -bordermode ignore 
    place $site_4_3.cpd63 \
        -in $site_4_3 -x 255 -y 55 -width 131 -height 38 -anchor nw \
        -bordermode ignore 
    place $site_4_3.cpd64 \
        -in $site_4_3 -x 395 -y 61 -width 180 -height 24 -anchor nw \
        -bordermode ignore 
    place $site_4_3.cpd65 \
        -in $site_4_3 -x 254 -y 26 -width 78 -height 22 -anchor nw \
        -bordermode ignore 
    $top.not63 raise page7
    menu $top.m64 \
        -tearoff 1 
    listbox $top.cpd66 \
        -yscrollcommand "$top.not63.fpage1.scr67 set" \
        -listvariable "$top\::lis66" 
    vTcl:DefineAlias "$top.cpd66" "varSelect1" vTcl:WidgetProc "Toplevel1" 1
    bind $top.cpd66 <FocusIn> {
        # TODO: your event handler here
    }
    ###################
    # SETTING GEOMETRY
    ###################
    place $top.not63 \
        -in $top -x 0 -y 0 -width 599 -height 416 -anchor nw \
        -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

#############################################################################
## Binding tag:  _TopLevel

bind "_TopLevel" <<Create>> {
    if {![info exists _topcount]} {set _topcount 0}; incr _topcount
}
bind "_TopLevel" <<DeleteWindow>> {
    if {[set ::%W::_modal]} {
                vTcl:Toplevel:WidgetProc %W endmodal
            } else {
                destroy %W; if {$_topcount == 0} {exit}
            }
}
bind "_TopLevel" <Destroy> {
    if {[winfo toplevel %W] == "%W"} {incr _topcount -1}
}

Window show .
Window show .top62

main $argc $argv
